@@ -1,7 +1,7 @@
 package Log::ger;
 
 our $DATE = '2017-06-28'; # DATE
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 #IFUNBUILT
 # # use strict;
@@ -316,7 +316,9 @@ sub init_target {
 # #         no warnings 'redefine';
 #END IFUNBUILT
         for my $r (@routines) {
-            my ($code, $name) = @$r;
+            my ($code, $name, $level, $flags) = @$r;
+            next if $flags & 2;
+            #print "D:installing $name to package $target_arg\n";
             *{"$target_arg\::$name"} = $code;
         }
     } elsif ($target eq 'object') {
@@ -326,12 +328,14 @@ sub init_target {
 #END IFUNBUILT
         my $pkg = ref $target_arg;
         for my $r (@routines) {
-            my ($code, $name) = @$r;
+            my ($code, $name, $level, $flags) = @$r;
+            next unless $flags & 2;
             *{"$pkg\::$name"} = $code;
         }
     } elsif ($target eq 'hash') {
         for my $r (@routines) {
-            my ($code, $name) = @$r;
+            my ($code, $name, $level, $flags) = @$r;
+            next if $flags & 2;
             $target_arg->{$name} = $code;
         }
     }
@@ -379,7 +383,7 @@ Log::ger - A lightweight, flexible logging framework
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -443,8 +447,8 @@ OO style. Log::ger can mimic the interface of L<Log::Any>, L<Log::Contextual>,
 L<Log::Log4perl>, or some other popular logging frameworks, to ease migration or
 adjust with your personal style.
 
-B<Per-package settings.> Each importer package can use its own format, output,
-or filter. For example, some modules that are migrated from Log::Any uses
+B<Per-package settings.> Each importer package can use its own format/layout,
+output. For example, some modules that are migrated from Log::Any uses
 Log::Any-style logging, while another uses native Log::ger style, and yet some
 other uses block formatting like Log::Contextual. This eases code migration and
 teamwork. Each module author can preserve her own logging style, if wanted, and
@@ -460,7 +464,7 @@ Log::Any logs (see L<Log::Any::Adapter::LogGer>) or produce logs to be consumed
 by Log::Any (see L<Log::ger::Output::LogAny>).
 
 B<Many output modules and plugins.> See C<Log::ger::Output::*>,
-C<Log::ger::Format::*>, C<Log::ger::Filter::*>, C<Log::ger::Plugin::*>. Writing
+C<Log::ger::Format::*>, C<Log::ger::Layout::*>, C<Log::ger::Plugin::*>. Writing
 an output module in Log::ger is easier than writing a Log::Any::Adapter::*.
 
 =back
